@@ -46,38 +46,58 @@ plot.bayestestR_eti <- function(x, ...) {
   NextMethod()
 }
 
+
 #' @export
 plot.bayestestR_si <- function(x, ...) {
   insight::check_if_installed("see", "to plot support intervals")
   NextMethod()
 }
 
+
 #' @export
 plot.bayesfactor_parameters <- function(x, ...) {
   insight::check_if_installed("see", "to plot Savage-Dickey Bayes factor")
   NextMethod()
 }
 
+
 #' @export
 plot.bayesfactor_models <- function(x, ...) {
   insight::check_if_installed("see", "to plot models' Bayes factors")
   NextMethod()
 }
 
+
 #' @export
 plot.estimate_density <- function(x, ...) {
   insight::check_if_installed("see", "to plot densities")
   NextMethod()
 }
 
+
 #' @export
 plot.estimate_density_df <- function(x, ...) {
   insight::check_if_installed("see", "to plot models' densities")
   NextMethod()
 }
 
+
 #' @export
 plot.p_significance <- function(x, ...) {
   insight::check_if_installed("see", "to plot practical significance")
   NextMethod()
 }
+
+
+#' @export
+plot.describe_posterior <- function(x, stack = FALSE, ...) {
+  insight::check_if_installed("see", "to plot posterior samples")
+  insight::check_if_installed("ggplot2", "to plot posterior samples")
+  model <- .retrieve_model(x)
+  if (!is.null(model)) {
+    graphics::plot(estimate_density(model), stack = stack, ...) +
+      ggplot2::labs(title = "Posterior Samples", x = NULL, y = NULL)
+  } else {
+    insight::format_alert("Could not find model-object. Try `plot(estimate_density(model))` instead.")
+  }
+}
