@@ -279,7 +279,7 @@ point_estimate.stanreg <- function(x,
                                    component = "location",
                                    parameters = NULL,
                                    ...) {
-  cleaned_parameters <- insight::clean_parameters(x)
+  cleaned_parameters <- .get_cleaned_parameters(x, ...)
 
   out <- .prepare_output(
     point_estimate(
@@ -321,7 +321,7 @@ point_estimate.brmsfit <- function(x,
                                    component = "conditional",
                                    parameters = NULL,
                                    ...) {
-  cleaned_parameters <- insight::clean_parameters(x)
+  cleaned_parameters <- .get_cleaned_parameters(x, ...)
 
   out <- .prepare_output(
     point_estimate(
