@@ -108,23 +108,23 @@
 #'   hdi(wp[1:5]) # between, but closer to pred_m1
 #' }
 #' }
+#'
 #' @references
-#' \itemize{
-#'   \item Clyde, M., Desimone, H., & Parmigiani, G. (1996). Prediction via
+#'
+#' - Clyde, M., Desimone, H., & Parmigiani, G. (1996). Prediction via
 #'   orthogonalized model mixing. Journal of the American Statistical
 #'   Association, 91(435), 1197-1208.
 #'
-#'   \item Hinne, M., Gronau, Q. F., van den Bergh, D., and Wagenmakers, E.
+#' - Hinne, M., Gronau, Q. F., van den Bergh, D., and Wagenmakers, E.
 #'   (2019, March 25). A conceptual introduction to Bayesian Model Averaging.
 #'   \doi{10.31234/osf.io/wgb64}
 #'
-#'   \item Rouder, J. N., Haaf, J. M., & Vandekerckhove, J. (2018). Bayesian
+#' - Rouder, J. N., Haaf, J. M., & Vandekerckhove, J. (2018). Bayesian
 #'   inference for psychology, part IV: Parameter estimation and Bayes factors.
 #'   Psychonomic bulletin & review, 25(1), 102-113.
 #'
-#'   \item van den Bergh, D., Haaf, J. M., Ly, A., Rouder, J. N., & Wagenmakers,
+#' - van den Bergh, D., Haaf, J. M., Ly, A., Rouder, J. N., & Wagenmakers,
 #'   E. J. (2019). A cautionary note on estimating effect size.
-#' }
 #'
 #' @export
 weighted_posteriors <- function(..., prior_odds = NULL, missing = 0, verbose = TRUE) {
@@ -171,12 +171,10 @@ weighted_posteriors.stanreg <- function(...,
                                         prior_odds = NULL,
                                         missing = 0,
                                         verbose = TRUE,
-                                        effects = c("fixed", "random", "all"),
-                                        component = c("conditional", "zi", "zero_inflated", "all"),
+                                        effects = "fixed",
+                                        component = "conditional",
                                         parameters = NULL) {
   Mods <- list(...)
-  effects <- match.arg(effects)
-  component <- match.arg(component)
 
   # Get Bayes factors
   BFMods <- bayesfactor_models(..., denominator = 1, verbose = verbose)
@@ -202,15 +200,13 @@ weighted_posteriors.stanreg <- function(...,
 }
 
 #' @export
-#' @rdname weighted_posteriors
 weighted_posteriors.brmsfit <- weighted_posteriors.stanreg
 
 #' @export
-#' @rdname weighted_posteriors
 weighted_posteriors.blavaan <- weighted_posteriors.stanreg
 
-#' @export
 #' @rdname weighted_posteriors
+#' @export
 weighted_posteriors.BFBayesFactor <- function(...,
                                               prior_odds = NULL,
                                               missing = 0,
