@@ -695,7 +695,7 @@ test_that("describe_posterior: BayesFactor", {
 
 test_that("describe_posterior: response column for marginaleffects", {
   skip_if_not(getRversion() >= "4.0", "Don't run with R < 4.0")
-  skip_if_not_installed("marginaleffects")
+  skip_if_not_installed("marginaleffects", minimum_version = "0.29.0")
   skip_if_not_installed("curl")
   skip_if_offline()
   skip_if_not_installed("httr2")
